package Locale::CLDR::Locales::Seh::Any;

# This file auto generated
#	on Fri 13 Oct  9:36:59 am GMT

use version;

our $VERSION = version->declare('v0.34.2');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Seh');

no Moo;

1;
